boxShadows property
boxShadows The shadows generated by Flushbar. You can use more than one if you feel the need.
Implementation
final List<BoxShadow>? boxShadows;
boxShadows The shadows generated by Flushbar. You can use more than one if you feel the need.
final List<BoxShadow>? boxShadows;