icon property

Widget? icon
getter/setter pair

You can use any widget here, but I recommend Icon or Image as indication of what kind of message you are displaying. Other widgets may break the layout

Implementation

Widget? icon;